==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/cs.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'cs', {
	button: {
		title: 'Vlastnosti tlačítka',
		text: 'Popisek',
		type: 'Typ',
		typeBtn: 'Tlačítko',
		typeSbm: 'Odeslat',
		typeRst: 'Obnovit'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Vlastnosti zaškrtávacího políčka',
		radioTitle: 'Vlastnosti přepínače',
		value: 'Hodnota',
		selected: 'Zaškrtnuto'
	},
	form: {
		title: 'Vlastnosti formuláře',
		menu: 'Vlastnosti formuláře',
		action: 'Akce',
		method: 'Metoda',
		encoding: 'Kódování'
	},
	hidden: {
		title: 'Vlastnosti skrytého pole',
		name: 'Název',
		value: 'Hodnota'
	},
	select: {
		title: 'Vlastnosti seznamu',
		selectInfo: 'Info',
		opAvail: 'Dostupná nastavení',
		value: 'Hodnota',
		size: 'Velikost',
		lines: 'Řádků',
		chkMulti: 'Povolit mnohonásobné výběry',
		opText: 'Text',
		opValue: 'Hodnota',
		btnAdd: 'Přidat',
		btnModify: 'Změnit',
		btnUp: 'Nahoru',
		btnDown: 'Dolů',
		btnSetValue: 'Nastavit jako vybranou hodnotu',
		btnDelete: 'Smazat'
	},
	textarea: {
		title: 'Vlastnosti textové oblasti',
		cols: 'Sloupců',
		rows: 'Řádků'
	},
	textfield: {
		title: 'Vlastnosti textového pole',
		name: 'Název',
		value: 'Hodnota',
		charWidth: 'Šířka ve znacích',
		maxChars: 'Maximální počet znaků',
		type: 'Typ',
		typeText: 'Text',
		typePass: 'Heslo',
		typeEmail: 'Email',
		typeSearch: 'Hledat',
		typeTel: 'Telefonní číslo',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/cs.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'cs', {
	button: {
		title: 'Vlastnosti tlačítka',
		text: 'Popisek',
		type: 'Typ',
		typeBtn: 'Tlačítko',
		typeSbm: 'Odeslat',
		typeRst: 'Obnovit'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Vlastnosti zaškrtávacího políčka',
		radioTitle: 'Vlastnosti přepínače',
		value: 'Hodnota',
		selected: 'Zaškrtnuto',
		required: 'Vyžadováno'
	},
	form: {
		title: 'Vlastnosti formuláře',
		menu: 'Vlastnosti formuláře',
		action: 'Akce',
		method: 'Metoda',
		encoding: 'Kódování'
	},
	hidden: {
		title: 'Vlastnosti skrytého pole',
		name: 'Název',
		value: 'Hodnota'
	},
	select: {
		title: 'Vlastnosti seznamu',
		selectInfo: 'Info',
		opAvail: 'Dostupná nastavení',
		value: 'Hodnota',
		size: 'Velikost',
		lines: 'Řádků',
		chkMulti: 'Povolit mnohonásobné výběry',
		required: 'Vyžadováno',
		opText: 'Text',
		opValue: 'Hodnota',
		btnAdd: 'Přidat',
		btnModify: 'Změnit',
		btnUp: 'Nahoru',
		btnDown: 'Dolů',
		btnSetValue: 'Nastavit jako vybranou hodnotu',
		btnDelete: 'Smazat'
	},
	textarea: {
		title: 'Vlastnosti textové oblasti',
		cols: 'Sloupců',
		rows: 'Řádků'
	},
	textfield: {
		title: 'Vlastnosti textového pole',
		name: 'Název',
		value: 'Hodnota',
		charWidth: 'Šířka ve znacích',
		maxChars: 'Maximální počet znaků',
		required: 'Vyžadováno',
		type: 'Typ',
		typeText: 'Text',
		typePass: 'Heslo',
		typeEmail: 'Email',
		typeSearch: 'Hledat',
		typeTel: 'Telefonní číslo',
		typeUrl: 'URL'
	}
} );
